<?php $TRANSLATIONS = array(
"Save" => "Պահպանել",
"Close" => "Փակել",
"Download" => "Բեռնել",
"Delete" => "Ջնջել",
"Other" => "Այլ",
"Description" => "Նկարագրություն"
);
